import { html } from 'lit';
import { describe, it, fixture, expect } from '@open-wc/testing';

import '../spinning-globe.js';

describe('SpinningGlobe', () => {
  it('has a default title "Hey there" and counter 5', async () => {
    const el = await fixture(html`<spinning-globe></spinning-globe>`);

    expect(el.title).to.equal('Hey there');
    expect(el.counter).to.equal(5);
  });

  it('increases the counter on button click', async () => {
    const el = await fixture(html`<spinning-globe></spinning-globe>`);
    el.shadowRoot.querySelector('button').click();

    expect(el.counter).to.equal(6);
  });

  it('can override the title via attribute', async () => {
    const el = await fixture(
      html`<spinning-globe title="attribute title"></spinning-globe>`
    );

    expect(el.title).to.equal('attribute title');
  });

  it('passes the a11y audit', async () => {
    const el = await fixture(html`<spinning-globe></spinning-globe>`);

    await expect(el).shadowDom.to.be.accessible();
  });
});
